deeplake.util.exceptions
========================
.. currentmodule:: deeplake.util.exceptions

.. autoclass:: ExternalCommandError
    :show-inheritance:

.. autoclass:: KaggleError
    :show-inheritance:

.. autoclass:: KaggleMissingCredentialsError
    :show-inheritance:

.. autoclass:: KaggleDatasetAlreadyDownloadedError
    :show-inheritance:

.. autoclass:: InvalidPathException
    :show-inheritance:
    
.. autoclass:: AutoCompressionError
    :show-inheritance:
    
.. autoclass:: InvalidFileExtension
    :show-inheritance:
    
.. autoclass:: SamePathException
    :show-inheritance:
    
.. autoclass:: TensorInvalidSampleShapeError
    :show-inheritance:
    
.. autoclass:: TensorMetaMissingKey
    :show-inheritance:
    
.. autoclass:: TensorDoesNotExistError
    :show-inheritance:
    
.. autoclass:: TensorAlreadyExistsError
    :show-inheritance:
    
.. autoclass:: TensorGroupDoesNotExistError
    :show-inheritance:
    
.. autoclass:: TensorGroupAlreadyExistsError
    :show-inheritance:
    
.. autoclass:: InvalidTensorNameError
    :show-inheritance:
    
.. autoclass:: InvalidTensorGroupNameError
    :show-inheritance:
    
.. autoclass:: DynamicTensorNumpyError
    :show-inheritance:
    
.. autoclass:: InvalidShapeIntervalError
    :show-inheritance:
    
.. autoclass:: InvalidKeyTypeError
    :show-inheritance:
    
.. autoclass:: UnsupportedTensorTypeError
    :show-inheritance:
    
.. autoclass:: InvalidBytesRequestedError
    :show-inheritance:
    
.. autoclass:: ProviderListEmptyError
    :show-inheritance:
    
.. autoclass:: DirectoryAtPathException
    :show-inheritance:
    
.. autoclass:: FileAtPathException
    :show-inheritance:
    
.. autoclass:: ProviderSizeListMismatch
    :show-inheritance:
    
.. autoclass:: ModuleNotInstalledException
    :show-inheritance:
    
.. autoclass:: LoginException
    :show-inheritance:
    
.. autoclass:: UserNotLoggedInException
    :show-inheritance:
    
.. autoclass:: InvalidHubPathException
    :show-inheritance:
    
.. autoclass:: PathNotEmptyException
    :show-inheritance:
    
.. autoclass:: AuthenticationException
    :show-inheritance:
    
.. autoclass:: AuthorizationException
    :show-inheritance:
    
.. autoclass:: InvalidPasswordException
    :show-inheritance:
    
.. autoclass:: CouldNotCreateNewDatasetException
    :show-inheritance:
    
.. autoclass:: ResourceNotFoundException
    :show-inheritance:
    
.. autoclass:: BadRequestException
    :show-inheritance:
    
.. autoclass:: OverLimitException
    :show-inheritance:
    
.. autoclass:: ServerException
    :show-inheritance:
    
.. autoclass:: BadGatewayException
    :show-inheritance:
    
.. autoclass:: GatewayTimeoutException
    :show-inheritance:
    
.. autoclass:: WaitTimeoutException
    :show-inheritance:
    
.. autoclass:: LockedException
    :show-inheritance:
    
.. autoclass:: UnexpectedStatusCodeException
    :show-inheritance:
    
.. autoclass:: EmptyTokenException
    :show-inheritance:
    
.. autoclass:: S3Error
    :show-inheritance:
    
.. autoclass:: S3GetError
    :show-inheritance:
    
.. autoclass:: S3SetError
    :show-inheritance:
    
.. autoclass:: S3DeletionError
    :show-inheritance:
    
.. autoclass:: S3ListError
    :show-inheritance:
    
.. autoclass:: UnsupportedCompressionError
    :show-inheritance:
    
.. autoclass:: SampleCompressionError
    :show-inheritance:
    
.. autoclass:: SampleDecompressionError
    :show-inheritance:
    
.. autoclass:: InvalidImageDimensions
    :show-inheritance:
    
.. autoclass:: TensorUnsupportedSampleType
    :show-inheritance:
    
.. autoclass:: MetaError
    :show-inheritance:
    
.. autoclass:: MetaDoesNotExistError
    :show-inheritance:
    
.. autoclass:: MetaAlreadyExistsError
    :show-inheritance:
    
.. autoclass:: MetaInvalidKey
    :show-inheritance:
    
.. autoclass:: MetaInvalidRequiredMetaKey
    :show-inheritance:
    
.. autoclass:: TensorMetaInvalidHtype
    :show-inheritance:
    
.. autoclass:: TensorMetaInvalidHtypeOverwriteValue
    :show-inheritance:
    
.. autoclass:: TensorMetaMissingRequiredValue
    :show-inheritance:
    
.. autoclass:: TensorMetaInvalidHtypeOverwriteKey
    :show-inheritance:
    
.. autoclass:: TensorDtypeMismatchError
    :show-inheritance:
    
.. autoclass:: InvalidTensorLinkError
    :show-inheritance:
    
.. autoclass:: TensorMetaMutuallyExclusiveKeysError
    :show-inheritance:
    
.. autoclass:: ReadOnlyModeError
    :show-inheritance:
    
.. autoclass:: TransformError  
    :show-inheritance:
    
.. autoclass:: FilterError
    :show-inheritance:
    
.. autoclass:: InvalidInputDataError
    :show-inheritance:
    
.. autoclass:: UnsupportedSchedulerError
    :show-inheritance:
    
.. autoclass:: TensorMismatchError
    :show-inheritance:
    
.. autoclass:: InvalidOutputDatasetError
    :show-inheritance:
    
.. autoclass:: InvalidTransformDataset
    :show-inheritance:
    
.. autoclass:: HubComposeEmptyListError
    :show-inheritance:
    
.. autoclass:: HubComposeIncompatibleFunction
    :show-inheritance:
    
.. autoclass:: DatasetUnsupportedPytorch
    :show-inheritance:
    
.. autoclass:: CorruptedMetaError
    :show-inheritance:
    
.. autoclass:: ChunkEngineError
    :show-inheritance:
    
.. autoclass:: FullChunkError
    :show-inheritance:
    
.. autoclass:: ChunkIdEncoderError
    :show-inheritance:
    
.. autoclass:: ChunkSizeTooSmallError
    :show-inheritance:
    
.. autoclass:: DatasetHandlerError
    :show-inheritance:
    
.. autoclass:: MemoryDatasetCanNotBePickledError
    :show-inheritance:
    
.. autoclass:: CorruptedSampleError
    :show-inheritance:
    
.. autoclass:: VersionControlError
    :show-inheritance:
    
.. autoclass:: MergeError
    :show-inheritance:
    
.. autoclass:: MergeNotSupportedError
    :show-inheritance:
    
.. autoclass:: MergeMismatchError
    :show-inheritance:
    
.. autoclass:: MergeConflictError
    :show-inheritance:
    
.. autoclass:: CheckoutError
    :show-inheritance:
    
.. autoclass:: CommitError
    :show-inheritance:
    
.. autoclass:: EmptyCommitError
    :show-inheritance:
    
.. autoclass:: TensorModifiedError
    :show-inheritance:
    
.. autoclass:: GCSDefaultCredsNotFoundError
    :show-inheritance:
    
.. autoclass:: InvalidOperationError
    :show-inheritance:
    
.. autoclass:: AgreementError
    :show-inheritance:
    
.. autoclass:: AgreementNotAcceptedError
    :show-inheritance:
    
.. autoclass:: NotLoggedInError
    :show-inheritance:
    
.. autoclass:: RenameError
    :show-inheritance:
    
.. autoclass:: BufferError
    :show-inheritance:
    
.. autoclass:: InfoError
    :show-inheritance:
    
.. autoclass:: OutOfChunkCountError
    :show-inheritance:
    
.. autoclass:: OutOfSampleCountError
    :show-inheritance:
    
.. autoclass:: SampleHtypeMismatchError
    :show-inheritance:
    
.. autoclass:: EmptyTensorError
    :show-inheritance:
    
.. autoclass:: DatasetViewSavingError
    :show-inheritance:
    
.. autoclass:: ManagedCredentialsNotFoundError
    :show-inheritance:
    
.. autoclass:: UnableToReadFromUrlError
    :show-inheritance:
    
.. autoclass:: InvalidTokenException
    :show-inheritance:
    
.. autoclass:: TokenPermissionError
    :show-inheritance:
    